/* |                |                |
 *  ALTITUDE
 *  Reset
 *                   
 *  RX VOLTAGE 1
 *  Calibrate Volt.  9.999V
 *  
 *  RX VOLTAGE 2
 *  Calibrate Volt.  9.999V
 *                   
 *  DRIVE VOLTAGE
 *  Calibrate Volt.  99.99V
 *  
 *  DRIVE CURRENT
 *  Calibrate Offset
 *  
 *  DRIVE CURRENT
 *  Calibrate Curr.  999.9A
 *  
 *  DRIVE CURRENT
 *  Set Scale        99.999A/V
 *                   
 *  PITOT PRESSURE
 *  Calibrate Offset
 *  
 *  PITOT PRESSURE
 *  Set Scale        9999.9Pa/V
 *                   
 *  AIRSPEED
 *  Set Ratio        9.999
 */


#define UP 0xd0
#define DOWN 0xb0
#define LEFT 0x70
#define RIGHT 0xe0

#define MENU_ALTITUDE_RESET 0
#define MENU_RX_VOLTAGE_1_CALIBRATE_VOLTAGE 1
#define MENU_RX_VOLTAGE_1_CALIBRATE_VOLTAGE_SET 10
#define MENU_RX_VOLTAGE_2_CALIBRATE_VOLTAGE 2
#define MENU_RX_VOLTAGE_2_CALIBRATE_VOLTAGE_SET 20
#define MENU_DRIVE_VOLTAGE_CALIBRATE_VOLTAGE 3
#define MENU_DRIVE_VOLTAGE_CALIBRATE_VOLTAGE_SET 30
#define MENU_DRIVE_CURRENT_CALIBRATE_OFFSET 4
#define MENU_DRIVE_CURRENT_CALIBRATE_CURRENT 5
#define MENU_DRIVE_CURRENT_CALIBRATE_CURRENT_SET 50
#define MENU_PITOT_PRESSURE_CALIBRATE_OFFSET 6
#define MENU_PITOT_PRESSURE_SET_SCALE 7
#define MENU_PITOT_PRESSURE_SET_SCALE_SET 70
#define MENU_AIRSPEED_SET_RATIO 8

int menu;
float setValue;
float setIncrement;
char _buffer[17];

void handleJetiBox() {
  byte key = jetiEx.GetJetiboxKey();
  if (key == 0) return;

  switch (menu) {
    case MENU_ALTITUDE_RESET:
      if (key == DOWN) {
        showJetiBoxMenu(MENU_RX_VOLTAGE_1_CALIBRATE_VOLTAGE);
      } else if (key == RIGHT) {
        initAltitude();
      }
      break;
      
    case MENU_RX_VOLTAGE_1_CALIBRATE_VOLTAGE:
      if (key == UP) {
        showJetiBoxMenu(MENU_ALTITUDE_RESET);
      } else if (key == DOWN) {
        showJetiBoxMenu(MENU_RX_VOLTAGE_2_CALIBRATE_VOLTAGE);
      } else if (key == RIGHT) {
        setValue = int(rxVoltage1 * 1000) / 1000;
        setIncrement = 1;
        showJetiBoxMenu(MENU_RX_VOLTAGE_1_CALIBRATE_VOLTAGE_SET);
      }
      break;

    case MENU_RX_VOLTAGE_1_CALIBRATE_VOLTAGE_SET:
      if (key == LEFT) {
        if (setIncrement < 0.5) {
          setIncrement *= 10;
        } else {
          showJetiBoxMenu(MENU_RX_VOLTAGE_1_CALIBRATE_VOLTAGE);
        }
      } else if (key == RIGHT) {
        if (setIncrement > 0.005) {
          setIncrement /= 10;
        } else if (setValue == 0) {
          set.rxVoltage1Scale = (5.1 + 5.1) / 5.1 * 5.0 / 1023;
          showJetiBoxMenu(MENU_RX_VOLTAGE_1_CALIBRATE_VOLTAGE);
        } else {
          set.rxVoltage1Scale = setValue / analogReadOversampling(RX_VOLTAGE_1_PIN, 16);
          showJetiBoxMenu(MENU_RX_VOLTAGE_1_CALIBRATE_VOLTAGE);
        }
      } else if (key == UP) {
        setValue += setIncrement;
        showJetiBoxMenu(MENU_RX_VOLTAGE_1_CALIBRATE_VOLTAGE_SET);
      } else if (key == DOWN) {
        setValue -= setIncrement;
        showJetiBoxMenu(MENU_RX_VOLTAGE_1_CALIBRATE_VOLTAGE_SET);
      }
      break;

    case MENU_RX_VOLTAGE_2_CALIBRATE_VOLTAGE:
      if (key == UP) {
        showJetiBoxMenu(MENU_ALTITUDE_RESET);
      } else if (key == DOWN) {
        showJetiBoxMenu(MENU_DRIVE_VOLTAGE_CALIBRATE_VOLTAGE);
      } else if (key == RIGHT) {
        setValue = int(rxVoltage2 * 1000) / 1000;
        setIncrement = 1;
        showJetiBoxMenu(MENU_RX_VOLTAGE_2_CALIBRATE_VOLTAGE_SET);
      }
      break;

    case MENU_RX_VOLTAGE_2_CALIBRATE_VOLTAGE_SET:
      if (key == LEFT) {
        if (setIncrement < 0.5) {
          setIncrement *= 10;
        } else {
          showJetiBoxMenu(MENU_RX_VOLTAGE_2_CALIBRATE_VOLTAGE);
        }
      } else if (key == RIGHT) {
        if (setIncrement > 0.005) {
          setIncrement /= 10;
        } else if (setValue == 0) {
          set.rxVoltage2Scale = (5.1 + 5.1) / 5.1 * 5.0 / 1023;
          showJetiBoxMenu(MENU_RX_VOLTAGE_2_CALIBRATE_VOLTAGE);
        } else {
          set.rxVoltage2Scale = setValue / analogReadOversampling(RX_VOLTAGE_2_PIN, 16);
          showJetiBoxMenu(MENU_RX_VOLTAGE_2_CALIBRATE_VOLTAGE);
        }
      } else if (key == UP) {
        setValue += setIncrement;
        showJetiBoxMenu(MENU_RX_VOLTAGE_2_CALIBRATE_VOLTAGE_SET);
      } else if (key == DOWN) {
        setValue -= setIncrement;
        showJetiBoxMenu(MENU_RX_VOLTAGE_2_CALIBRATE_VOLTAGE_SET);
      }
      break;

    case MENU_DRIVE_VOLTAGE_CALIBRATE_VOLTAGE:
      if (key == UP) {
        showJetiBoxMenu(MENU_RX_VOLTAGE_2_CALIBRATE_VOLTAGE);
      } else if (key == DOWN) {
        showJetiBoxMenu(MENU_DRIVE_CURRENT_CALIBRATE_OFFSET);
      } else if (key == RIGHT) {
        setValue = int(driveVoltage * 100) / 100;
        setIncrement = 10;
        showJetiBoxMenu(MENU_DRIVE_VOLTAGE_CALIBRATE_VOLTAGE_SET);
      }
      break;

    case MENU_DRIVE_VOLTAGE_CALIBRATE_VOLTAGE_SET:
      if (key == LEFT) {
        if (setIncrement < 5) {
          setIncrement *= 10;
        } else {
          showJetiBoxMenu(MENU_DRIVE_VOLTAGE_CALIBRATE_VOLTAGE);
        }
      } else if (key == RIGHT) {
        if (setIncrement > 0.05) {
          setIncrement /= 10;
        } else if (setValue == 0) {
          set.driveVoltageScale = (51 + 5.1) / 5.1 * 5.0 / 1023;
          showJetiBoxMenu(MENU_DRIVE_VOLTAGE_CALIBRATE_VOLTAGE);
        } else {
          set.driveVoltageScale = setValue / analogReadOversampling(DRIVE_VOLTAGE_PIN, 16);
          showJetiBoxMenu(MENU_DRIVE_VOLTAGE_CALIBRATE_VOLTAGE);
        }
      } else if (key == UP) {
        setValue += setIncrement;
        showJetiBoxMenu(MENU_DRIVE_VOLTAGE_CALIBRATE_VOLTAGE_SET);
      } else if (key == DOWN) {
        setValue -= setIncrement;
        showJetiBoxMenu(MENU_DRIVE_VOLTAGE_CALIBRATE_VOLTAGE_SET);
      }
      break;
  }
}

void showJetiBoxMenu(int menuNew) {
  menu = menuNew;
  
  switch (menu) {
    case MENU_ALTITUDE_RESET:
      jetiEx.SetJetiboxText(JetiExProtocol::LINE1, "ALTITUDE");
      jetiEx.SetJetiboxText(JetiExProtocol::LINE2, "Reset");
      break;
      
    case MENU_RX_VOLTAGE_1_CALIBRATE_VOLTAGE:
      jetiEx.SetJetiboxText(JetiExProtocol::LINE1, "RX VOLTAGE 1");
      jetiEx.SetJetiboxText(JetiExProtocol::LINE2, "Calibrate Volt.");
      break;
    case MENU_RX_VOLTAGE_1_CALIBRATE_VOLTAGE_SET:
      sprintf(_buffer, "%1d.%03dV", int(setValue), int(setValue * 1000) % 1000);
      jetiEx.SetJetiboxText(JetiExProtocol::LINE2, _buffer);
      break;
      
    case MENU_RX_VOLTAGE_2_CALIBRATE_VOLTAGE:
      jetiEx.SetJetiboxText(JetiExProtocol::LINE1, "RX VOLTAGE 2");
      jetiEx.SetJetiboxText(JetiExProtocol::LINE2, "Calibrate Volt.");
      break;
    case MENU_RX_VOLTAGE_2_CALIBRATE_VOLTAGE_SET:
      sprintf(_buffer, "%1d.%03dV", int(setValue), int(setValue * 1000) % 1000);
      jetiEx.SetJetiboxText(JetiExProtocol::LINE2, _buffer);
      break;
      
    case MENU_DRIVE_VOLTAGE_CALIBRATE_VOLTAGE:
      jetiEx.SetJetiboxText(JetiExProtocol::LINE1, "DRIVE VOLTAGE");
      jetiEx.SetJetiboxText(JetiExProtocol::LINE2, "Calibrate Volt.");
      break;
    case MENU_DRIVE_VOLTAGE_CALIBRATE_VOLTAGE_SET:
      sprintf(_buffer, "%2d.%02dV", int(setValue), int(setValue * 100) % 100);
      jetiEx.SetJetiboxText(JetiExProtocol::LINE2, _buffer);
      break;
  }
}

